Index: code/branches/cpp11_v2/src/orxonox/CameraManager.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/CameraManager.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/CameraManager.cc	(revision 10765)
@@ -93,5 +93,5 @@
                 this->cameraList_.front()->setFocus();
             else
-                this->useCamera(NULL);
+                this->useCamera(nullptr);
         }
         else
Index: code/branches/cpp11_v2/src/orxonox/LevelManager.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/LevelManager.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/LevelManager.cc	(revision 10765)
@@ -154,5 +154,5 @@
         Get the currently active Level.
     @return
-        Returns a pointer to the currently active level or NULL if there currently are no active Levels.
+        Returns a pointer to the currently active level or nullptr if there currently are no active Levels.
     */
     Level* LevelManager::getActiveLevel()
@@ -218,5 +218,5 @@
     {
         if(index >= this->availableLevels_.size())
-            return NULL;
+            return nullptr;
 
         // If this index directly follows the last we can optimize a lot.
@@ -272,5 +272,5 @@
             if (it->find("old/") != 0)
             {
-                LevelInfoItem* info = NULL;
+                LevelInfoItem* info = nullptr;
 
                 // Load the LevelInfo object from the level file.
@@ -286,5 +286,5 @@
                 Loader::getInstance().unload(&file);
 
-                if(info == NULL)
+                if(info == nullptr)
                 {
                     // Create a default LevelInfoItem object that merely contains the name
Index: code/branches/cpp11_v2/src/orxonox/Scene.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/Scene.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/Scene.cc	(revision 10765)
@@ -66,5 +66,5 @@
         this->bShadows_ = true;
         this->bDebugDrawPhysics_ = false;
-        this->debugDrawer_ = NULL;
+        this->debugDrawer_ = nullptr;
         this->soundReferenceDistance_ = 20.0;
         this->bIsUpdatingPhysics_ = false;
Index: code/branches/cpp11_v2/src/orxonox/chat/ChatInputHandler.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/chat/ChatInputHandler.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/chat/ChatInputHandler.cc	(revision 10765)
@@ -79,5 +79,5 @@
     this->inpbuf = new InputBuffer();
     this->disp_offset = 0;
-    assert( this->inpbuf != NULL );
+    assert( this->inpbuf != nullptr );
 
     /* generate chatbox ui and chatbox-inputonly ui */
Index: code/branches/cpp11_v2/src/orxonox/collisionshapes/CollisionShape.h
===================================================================
--- code/branches/cpp11_v2/src/orxonox/collisionshapes/CollisionShape.h	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/collisionshapes/CollisionShape.h	(revision 10765)
@@ -181,5 +181,5 @@
 
             btCollisionShape*       collisionShape_; //!< The bullet collision shape of this CollisionShape.
-            CompoundCollisionShape* parent_; //!< The CompoundCollisionShape this CollisionShape belongs to, NULL if it doesn't belong to one.
+            CompoundCollisionShape* parent_; //!< The CompoundCollisionShape this CollisionShape belongs to, nullptr if it doesn't belong to one.
             unsigned int            parentID_; //!< The objectID of the parent of this CollisionShape, which can either be a CompoundCollisionShape or a WorldEntity.
 
Index: code/branches/cpp11_v2/src/orxonox/collisionshapes/WorldEntityCollisionShape.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/collisionshapes/WorldEntityCollisionShape.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/collisionshapes/WorldEntityCollisionShape.cc	(revision 10765)
@@ -43,5 +43,5 @@
         RegisterObject(WorldEntityCollisionShape);
 
-        this->worldEntityOwner_ = NULL;
+        this->worldEntityOwner_ = nullptr;
         // suppress synchronisation
         this->setSyncMode(ObjectDirection::None);
Index: code/branches/cpp11_v2/src/orxonox/controllers/AIController.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/controllers/AIController.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/controllers/AIController.cc	(revision 10765)
@@ -249,5 +249,5 @@
             }
             else
-                this->setPreviousMode();//If bot dies -> getControllableEntity == NULL -> get out of ROCKET mode
+                this->setPreviousMode();//If bot dies -> getControllableEntity == nullptr -> get out of ROCKET mode
         }//END_OF ROCKET MODE
 
Index: code/branches/cpp11_v2/src/orxonox/controllers/ArtificialController.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/controllers/ArtificialController.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/controllers/ArtificialController.cc	(revision 10765)
@@ -56,5 +56,5 @@
         this->currentWaypoint_ = 0;
         this->setAccuracy(5);
-        this->defaultWaypoint_ = NULL;
+        this->defaultWaypoint_ = nullptr;
         this->mode_ = DEFAULT;//Vector-implementation: mode_.push_back(DEFAULT);
     }
@@ -222,5 +222,5 @@
     {
         SpaceShip* ship = orxonox_cast<SpaceShip*>(this->getControllableEntity());
-        if(ship == NULL) return;
+        if(ship == nullptr) return;
         if(ship->getBoostPower()*1.5f > ship->getInitialBoostPower() ) //upper limit ->boost
             this->getControllableEntity()->boost(true);
@@ -258,5 +258,5 @@
     void ArtificialController::updatePointsOfInterest(std::string name, float searchDistance)
     {
-        WorldEntity* waypoint = NULL;
+        WorldEntity* waypoint = nullptr;
         for (WorldEntity* we : ObjectList<WorldEntity>())
         {
Index: code/branches/cpp11_v2/src/orxonox/controllers/ControllerDirector.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/controllers/ControllerDirector.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/controllers/ControllerDirector.cc	(revision 10765)
@@ -32,7 +32,7 @@
 
         // Initialize member variables
-        this->player_ = NULL;
-        this->entity_ = NULL;
-        this->pTrigger_ = NULL;
+        this->player_ = nullptr;
+        this->entity_ = nullptr;
+        this->pTrigger_ = nullptr;
         this->context_ = context;
     }
@@ -110,10 +110,10 @@
     {
         this->pTrigger_ = orxonox_cast<PlayerTrigger*>(trigger);
-        this->player_ = NULL;
+        this->player_ = nullptr;
 
         orxout(verbose) << "Preparation to take Control!" << endl; 
 
         // Check whether it is a player trigger and extract pawn from it
-        if(this->pTrigger_ != NULL)
+        if(this->pTrigger_ != nullptr)
         {
             // Get the object which triggered the event.
@@ -121,5 +121,5 @@
 
             // Check if there actually was a player returned.
-            if( this->player_ == NULL) return false;
+            if( this->player_ == nullptr) return false;
         }
         else
Index: code/branches/cpp11_v2/src/orxonox/controllers/FormationController.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/controllers/FormationController.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/controllers/FormationController.cc	(revision 10765)
@@ -773,6 +773,6 @@
     {
 
-        Pawn *humanPawn = NULL;
-        NewHumanController *currentHumanController = NULL;
+        Pawn *humanPawn = nullptr;
+        NewHumanController *currentHumanController = nullptr;
         std::vector<FormationController*> allMasters;
 
@@ -800,5 +800,5 @@
         }
 
-        if((humanPawn != NULL) && (allMasters.size() != 0))
+        if((humanPawn != nullptr) && (allMasters.size() != 0))
         {
             float posHuman = humanPawn->getPosition().length();
@@ -826,5 +826,5 @@
     void FormationController::followInit(Pawn* pawn, const bool always, const int secondsToFollow)
     {
-        if (pawn == NULL || this->state_ != MASTER)
+        if (pawn == nullptr || this->state_ != MASTER)
             return;
         this->specificMasterAction_  =  FOLLOW;
@@ -844,6 +844,6 @@
     {
 
-        Pawn *humanPawn = NULL;
-        NewHumanController *currentHumanController = NULL;
+        Pawn *humanPawn = nullptr;
+        NewHumanController *currentHumanController = nullptr;
 
         for (ObjectList<Pawn>::iterator it = ObjectList<Pawn>::begin(); it; ++it)
@@ -861,5 +861,5 @@
         }
 
-        if((humanPawn != NULL))
+        if((humanPawn != nullptr))
                 this->followInit(humanPawn);
     }
Index: code/branches/cpp11_v2/src/orxonox/controllers/HumanController.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/controllers/HumanController.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/controllers/HumanController.cc	(revision 10765)
@@ -321,5 +321,5 @@
             return orxonox_cast<Pawn*>(HumanController::localController_s->getControllableEntity());
         else
-            return NULL;
+            return nullptr;
     }
 
Index: code/branches/cpp11_v2/src/orxonox/controllers/NewHumanController.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/controllers/NewHumanController.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/controllers/NewHumanController.cc	(revision 10765)
@@ -62,18 +62,18 @@
     NewHumanController::NewHumanController(Context* context)
         : HumanController(context)
-        , crossHairOverlay_(NULL)
-        , centerOverlay_(NULL)
-        , damageOverlayTop_(NULL)
-        , damageOverlayRight_(NULL)
-        , damageOverlayBottom_(NULL)
-        , damageOverlayLeft_(NULL)
+        , crossHairOverlay_(nullptr)
+        , centerOverlay_(nullptr)
+        , damageOverlayTop_(nullptr)
+        , damageOverlayRight_(nullptr)
+        , damageOverlayBottom_(nullptr)
+        , damageOverlayLeft_(nullptr)
         , damageOverlayTT_(0)
         , damageOverlayTR_(0)
         , damageOverlayTB_(0)
         , damageOverlayTL_(0)
-        , arrowsOverlay1_(NULL)
-        , arrowsOverlay2_(NULL)
-        , arrowsOverlay3_(NULL)
-        , arrowsOverlay4_(NULL)
+        , arrowsOverlay1_(nullptr)
+        , arrowsOverlay2_(nullptr)
+        , arrowsOverlay3_(nullptr)
+        , arrowsOverlay4_(nullptr)
     {
         RegisterObject(NewHumanController);
Index: code/branches/cpp11_v2/src/orxonox/controllers/ScriptController.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/controllers/ScriptController.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/controllers/ScriptController.cc	(revision 10765)
@@ -64,6 +64,6 @@
         /* Set default values for all variables */
         /* - pointers to zero */
-        this->player_ = NULL;
-        this->entity_ = NULL;
+        this->player_ = nullptr;
+        this->entity_ = nullptr;
 
         /* - times */
@@ -138,5 +138,5 @@
       
       }
-      return NULL;
+      return nullptr;
     }
 
Index: code/branches/cpp11_v2/src/orxonox/gamestates/GSLevel.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/gamestates/GSLevel.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/gamestates/GSLevel.cc	(revision 10765)
@@ -156,5 +156,5 @@
         {
             ModifyConsoleCommand(__CC_changeGame_name).deactivate();
-            ModifyConsoleCommand(__CC_reloadLevel_name).setObject(NULL).deactivate();
+            ModifyConsoleCommand(__CC_reloadLevel_name).setObject(nullptr).deactivate();
         }
     }
Index: code/branches/cpp11_v2/src/orxonox/gamestates/GSLevelMemento.h
===================================================================
--- code/branches/cpp11_v2/src/orxonox/gamestates/GSLevelMemento.h	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/gamestates/GSLevelMemento.h	(revision 10765)
@@ -48,5 +48,5 @@
         protected:
             /**
-             * Returns the state of this memento. Returns NULL if no state needed to persist.
+             * Returns the state of this memento. Returns nullptr if no state needed to persist.
              */
             virtual GSLevelMementoState* exportMementoState() = 0;
Index: code/branches/cpp11_v2/src/orxonox/gamestates/GSMainMenu.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/gamestates/GSMainMenu.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/gamestates/GSMainMenu.cc	(revision 10765)
@@ -73,5 +73,5 @@
 
         // create an empty Scene
-        this->scene_ = new Scene(NULL);
+        this->scene_ = new Scene(nullptr);
         this->scene_->setSyncMode( 0x0 );
         // and a Camera
Index: code/branches/cpp11_v2/src/orxonox/gametypes/Gametype.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/gametypes/Gametype.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/gametypes/Gametype.cc	(revision 10765)
@@ -92,6 +92,6 @@
                 this->gtinfo_->destroy();
 
-            ModifyConsoleCommand(__CC_addBots_name).setObject(NULL);
-            ModifyConsoleCommand(__CC_killBots_name).setObject(NULL);
+            ModifyConsoleCommand(__CC_addBots_name).setObject(nullptr);
+            ModifyConsoleCommand(__CC_killBots_name).setObject(nullptr);
         }
     }
@@ -337,5 +337,5 @@
         {
             // Fallback spawn point if there is no active one, choose a random one.
-            SpawnPoint* fallbackSpawnPoint = NULL;
+            SpawnPoint* fallbackSpawnPoint = nullptr;
             unsigned int randomspawn = static_cast<unsigned int>(rnd(static_cast<float>(this->spawnpoints_.size())));
             unsigned int index = 0;
@@ -346,5 +346,5 @@
                     fallbackSpawnPoint = (*it);
 
-                if (*it != NULL && (*it)->isActive())
+                if (*it != nullptr && (*it)->isActive())
                     activeSpawnPoints.push_back(*it);
 
@@ -552,5 +552,5 @@
         }
 
-        return NULL;
+        return nullptr;
     }
 
@@ -558,5 +558,5 @@
     {
         // find correct memento state
-        GametypeMementoState* state = NULL;
+        GametypeMementoState* state = nullptr;
         for (size_t i = 0; i < states.size(); ++i)
         {
@@ -570,5 +570,5 @@
 
         // find correct scene
-        Scene* scene = NULL;
+        Scene* scene = nullptr;
         for (ObjectList<Scene>::iterator it = ObjectList<Scene>::begin(); it != ObjectList<Scene>::end(); ++it)
         {
Index: code/branches/cpp11_v2/src/orxonox/gametypes/TeamGametype.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/gametypes/TeamGametype.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/gametypes/TeamGametype.cc	(revision 10765)
@@ -75,5 +75,5 @@
     void TeamGametype::playerEntered(PlayerInfo* player)
     {
-        if(player == NULL) return; // catch null pointers
+        if(player == nullptr) return; // catch null pointers
         Gametype::playerEntered(player);
         this->findAndSetTeam(player);
@@ -96,5 +96,5 @@
     void TeamGametype::findAndSetTeam(PlayerInfo* player)
     {
-        if(player == NULL) return; // catch null pointers
+        if(player == nullptr) return; // catch null pointers
         std::vector<unsigned int> playersperteam(this->teams_, 0);
 
@@ -235,5 +235,5 @@
         }
 
-        SpawnPoint* fallbackSpawnPoint = NULL;
+        SpawnPoint* fallbackSpawnPoint = nullptr;
         if (teamSpawnPoints.size() > 0)
         {
@@ -328,5 +328,5 @@
     void TeamGametype::setDefaultObjectColour(Pawn* pawn)
     {
-        if(pawn == NULL)
+        if(pawn == nullptr)
             return;
 
@@ -350,5 +350,5 @@
         ArtificialController* artificial =  orxonox_cast<ArtificialController*>(controller);
         //get Teamnumber - get the data
-        if(artificial == NULL)
+        if(artificial == nullptr)
             return;
         teamnumber= artificial->getTeam();
@@ -360,5 +360,5 @@
     void TeamGametype::colourPawn(Pawn* pawn, int teamNr)
     {// catch: no-colouring-case and wrong input
-        if(teamNr < 0 || teamNr+1 > int(this->teamcolours_.size()) ||pawn == NULL) return;
+        if(teamNr < 0 || teamNr+1 > int(this->teamcolours_.size()) ||pawn == nullptr) return;
         pawn->setRadarObjectColour(this->teamcolours_[teamNr]);
 
Index: code/branches/cpp11_v2/src/orxonox/graphics/Billboard.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/graphics/Billboard.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/graphics/Billboard.cc	(revision 10765)
@@ -139,5 +139,5 @@
     {
         Ogre::BillboardSet* bSet = this->billboard_.getBillboardSet();
-        if( bSet != NULL )
+        if( bSet != nullptr )
         {
             bSet->setBillboardType(bbt);
@@ -148,5 +148,5 @@
     {
         Ogre::BillboardSet* bSet = this->billboard_.getBillboardSet();
-        if( bSet != NULL )
+        if( bSet != nullptr )
         {
             bSet->setCommonDirection( vec );
@@ -157,5 +157,5 @@
     {
         Ogre::BillboardSet* bSet = this->billboard_.getBillboardSet();
-        if( bSet != NULL )
+        if( bSet != nullptr )
         {
             bSet->setCommonUpVector( vec );
@@ -166,5 +166,5 @@
     {
         Ogre::BillboardSet* bSet = this->billboard_.getBillboardSet();
-        if( bSet != NULL )
+        if( bSet != nullptr )
         {
             bSet->setDefaultDimensions(width, height);
Index: code/branches/cpp11_v2/src/orxonox/graphics/Model.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/graphics/Model.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/graphics/Model.cc	(revision 10765)
@@ -157,5 +157,5 @@
                 BaseObject* creatorPtr = this;
 
-                while(creatorPtr!=NULL&&orxonox_cast<WorldEntity*>(creatorPtr))
+                while(creatorPtr!=nullptr&&orxonox_cast<WorldEntity*>(creatorPtr))
                 {
                     scaleFactor *= getBiggestScale(((WorldEntity*) creatorPtr)->getScale3D());
Index: code/branches/cpp11_v2/src/orxonox/infos/PlayerInfo.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/infos/PlayerInfo.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/infos/PlayerInfo.cc	(revision 10765)
@@ -181,5 +181,5 @@
 
         RadarViewable* radarviewable = orxonox_cast<RadarViewable*>(entity);
-        if (radarviewable != NULL)
+        if (radarviewable != nullptr)
             radarviewable->setRadarName(this->getName());
     }
@@ -235,11 +235,11 @@
 
         Controller* tmp =this->controllableEntity_->getController();
-        if (tmp == NULL)
-        {
-            orxout(verbose) <<  "PlayerInfo: pauseControl, Controller is NULL " << endl;
+        if (tmp == nullptr)
+        {
+            orxout(verbose) <<  "PlayerInfo: pauseControl, Controller is nullptr " << endl;
             return;
         }
         tmp->setActive(false);
-        //this->controllableEntity_->getController()->setControllableEntity(NULL);
+        //this->controllableEntity_->getController()->setControllableEntity(nullptr);
         this->controllableEntity_->setController(0);
     }
@@ -249,5 +249,5 @@
         ControllableEntity* entity = this->controllableEntity_;
 
-        assert(this->controllableEntity_ != NULL);
+        assert(this->controllableEntity_ != nullptr);
         if( !entity || this->previousControllableEntity_.size() == 0 )
             return;
@@ -260,13 +260,13 @@
         do {
             this->controllableEntity_ = this->previousControllableEntity_.back();
-        } while(this->controllableEntity_ == NULL && this->previousControllableEntity_.size() > 0);
+        } while(this->controllableEntity_ == nullptr && this->previousControllableEntity_.size() > 0);
         this->controllableEntityID_ = this->controllableEntity_->getObjectID();
         this->previousControllableEntity_.pop_back();
 
-        if ( this->controllableEntity_ != NULL && this->controller_ != NULL)
+        if ( this->controllableEntity_ != nullptr && this->controller_ != nullptr)
             this->controller_->setControllableEntity(this->controllableEntity_);
 
          // HACK-ish
-        if(this->controllableEntity_ != NULL && this->isHumanPlayer())
+        if(this->controllableEntity_ != nullptr && this->isHumanPlayer())
             this->controllableEntity_->createHud();
 
Index: code/branches/cpp11_v2/src/orxonox/interfaces/PickupCarrier.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/interfaces/PickupCarrier.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/interfaces/PickupCarrier.cc	(revision 10765)
@@ -127,10 +127,10 @@
     {
         if(!this->isTarget(pickup))
-            return NULL;
+            return nullptr;
 
         if(pickup->isTarget(this)) // If the PickupCarrier itself is a target.
             return this;
 
-        PickupCarrier* target = NULL;
+        PickupCarrier* target = nullptr;
         // Go recursively through all children to check whether they are the target.
         std::vector<PickupCarrier*>* children = this->getCarrierChildren();
Index: code/branches/cpp11_v2/src/orxonox/interfaces/PickupCarrier.h
===================================================================
--- code/branches/cpp11_v2/src/orxonox/interfaces/PickupCarrier.h	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/interfaces/PickupCarrier.h	(revision 10765)
@@ -59,5 +59,5 @@
         But this structure has to be established first.
         - <b>getCarrierChildren()</b> To this end a PickupCarrier needs to implement getCarrierChildren() which returns a list of its direct PickupCarrier children. If you need an example, have a look at @ref orxonox::Pawn "Pawn" and @ref orxonox::Engine "Engine".
-        - <b>getCarrierParent()</b> This is the method in the other direction. It returns the parent of this PickupCarrier, or NULL if the PickupCarrier is a root node in this hierarchy.
+        - <b>getCarrierParent()</b> This is the method in the other direction. It returns the parent of this PickupCarrier, or nullptr if the PickupCarrier is a root node in this hierarchy.
 
     @author
Index: code/branches/cpp11_v2/src/orxonox/items/Engine.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/items/Engine.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/items/Engine.cc	(revision 10765)
@@ -155,5 +155,5 @@
     void Engine::run(float dt)
     {
-        if (this->ship_ == NULL)
+        if (this->ship_ == nullptr)
         {
             if (this->shipID_ != 0)
@@ -161,5 +161,5 @@
                 this->networkcallback_shipID();
 
-                if (this->ship_ == NULL)
+                if (this->ship_ == nullptr)
                     return;
             }
Index: code/branches/cpp11_v2/src/orxonox/items/Engine.h
===================================================================
--- code/branches/cpp11_v2/src/orxonox/items/Engine.h	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/items/Engine.h	(revision 10765)
@@ -67,5 +67,5 @@
             /**
             @brief Get the SpaceShip this Engine is mounted on.
-            @return Returns a pointer to the SpaceShip. NULL if it isn't mounted on any ship.
+            @return Returns a pointer to the SpaceShip. nullptr if it isn't mounted on any ship.
             */
             inline SpaceShip* getShip() const
Index: code/branches/cpp11_v2/src/orxonox/items/MultiStateEngine.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/items/MultiStateEngine.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/items/MultiStateEngine.cc	(revision 10765)
@@ -205,5 +205,5 @@
     void MultiStateEngine::addEffectContainer(EffectContainer* effect)
     {
-        if (effect == NULL)
+        if (effect == nullptr)
             return;
         effect->setLuaState(this->lua_, 'f' + multi_cast<std::string>(this->effectContainers_.size()));
@@ -224,5 +224,5 @@
                 return (*it);
         }
-        return NULL;
+        return nullptr;
     }
 
Index: code/branches/cpp11_v2/src/orxonox/items/ShipPart.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/items/ShipPart.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/items/ShipPart.cc	(revision 10765)
@@ -50,5 +50,5 @@
 
     ShipPart::ShipPart(Context* context)
-        : Item(context), parent_(NULL)
+        : Item(context), parent_(nullptr)
     {
         RegisterObject(ShipPart);
@@ -122,5 +122,5 @@
     void ShipPart::addEntity(StaticEntity* entity)
     {
-        OrxAssert(entity != NULL, "The Entity cannot be NULL.");
+        OrxAssert(entity != nullptr, "The Entity cannot be nullptr.");
         this->entityList_.push_back(entity);
     }
@@ -130,10 +130,10 @@
         Get the i-th StaticEntity of the ShipPart.
     @return
-        Returns a pointer to the i-the StaticEntity. NULL if there is no StaticEntity with that index.
+        Returns a pointer to the i-the StaticEntity. nullptr if there is no StaticEntity with that index.
     */
     StaticEntity* ShipPart::getEntity(unsigned int index)
     {
         if(this->entityList_.size() >= index)
-            return NULL;
+            return nullptr;
         else
             return this->entityList_[index];
@@ -164,5 +164,5 @@
     void ShipPart::addDestructionEvent(PartDestructionEvent* event)
     {
-        OrxAssert(event != NULL, "The PartDestructionEvent cannot be NULL.");
+        OrxAssert(event != nullptr, "The PartDestructionEvent cannot be nullptr.");
         event->setParent(this);
         this->eventList_.push_back(event);
@@ -173,10 +173,10 @@
         Get the i-th PartDestructionEvent of the ShipPart.
     @return
-        Returns a pointer to the i-the PartDestructionEvent. NULL if there is no PartDestructionEvent with that index.
+        Returns a pointer to the i-the PartDestructionEvent. nullptr if there is no PartDestructionEvent with that index.
     */
     PartDestructionEvent* ShipPart::getDestructionEvent(unsigned int index)
     {
         if(this->eventList_.size() <= index)
-            return NULL;
+            return nullptr;
         else
             return this->eventList_[index];
Index: code/branches/cpp11_v2/src/orxonox/sound/AmbientSound.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/sound/AmbientSound.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/sound/AmbientSound.cc	(revision 10765)
@@ -93,5 +93,5 @@
             const std::string& path = "ambient/" + mood + '/' + this->ambientSource_;
             shared_ptr<ResourceInfo> fileInfo = Resource::getInfo(path);
-            if (fileInfo != NULL)
+            if (fileInfo != nullptr)
             {
                 orxout(user_info) << "Loading ambient sound " << path << "..." << endl; // TODO: make this output internal if we implement sound streaming
Index: code/branches/cpp11_v2/src/orxonox/sound/BaseSound.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/sound/BaseSound.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/sound/BaseSound.cc	(revision 10765)
@@ -66,5 +66,5 @@
             this->stop();
         // Release buffer
-        if (this->soundBuffer_ != NULL)
+        if (this->soundBuffer_ != nullptr)
         {
             assert(GameMode::playsSound());
@@ -84,5 +84,5 @@
     {
         this->state_ = Playing;
-        if (GameMode::playsSound() && this->getSourceState() != AL_PLAYING && this->soundBuffer_ != NULL)
+        if (GameMode::playsSound() && this->getSourceState() != AL_PLAYING && this->soundBuffer_ != nullptr)
         {
             if (!alIsSource(this->audioSource_))
@@ -151,5 +151,5 @@
             orxout(internal_warning, context::sound) << "Setting source parameters to 0 failed: "
                                                      << SoundManager::getALErrorString(error) << endl;
-        assert(this->soundBuffer_ != NULL);
+        assert(this->soundBuffer_ != nullptr);
         alSourcei(this->audioSource_, AL_BUFFER, this->soundBuffer_->getBuffer());
         if (ALuint error = alGetError())
@@ -209,5 +209,5 @@
         }
 
-        if (this->soundBuffer_ != NULL)
+        if (this->soundBuffer_ != nullptr)
         {
             if (this->soundBuffer_->getFilename() == source)
@@ -233,5 +233,5 @@
         // Get new sound buffer
         this->soundBuffer_ = SoundManager::getInstance().getSoundBuffer(this->source_);
-        if (this->soundBuffer_ == NULL)
+        if (this->soundBuffer_ == nullptr)
             return;
 
Index: code/branches/cpp11_v2/src/orxonox/sound/SoundBuffer.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/sound/SoundBuffer.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/sound/SoundBuffer.cc	(revision 10765)
@@ -45,9 +45,9 @@
     {
         if (this->filename_.empty())
-            ThrowException(General, "SoundBuffer construction: fileInfo was NULL");
+            ThrowException(General, "SoundBuffer construction: fileInfo was nullptr");
 
         // Get resource info
         shared_ptr<ResourceInfo> fileInfo = Resource::getInfo(filename);
-        if (fileInfo == NULL)
+        if (fileInfo == nullptr)
         {
             orxout(internal_error, context::sound) << "Sound file '" << filename << "' not found" << endl;
@@ -138,8 +138,8 @@
         vorbisCallbacks.seek_func  = &seekVorbis;
         vorbisCallbacks.tell_func  = &tellVorbis;
-        vorbisCallbacks.close_func = NULL;
+        vorbisCallbacks.close_func = nullptr;
 
         OggVorbis_File vf;
-        int ret = ov_open_callbacks(dataStream.get(), &vf, NULL, 0, vorbisCallbacks);
+        int ret = ov_open_callbacks(dataStream.get(), &vf, nullptr, 0, vorbisCallbacks);
         if (ret < 0)
         {
Index: code/branches/cpp11_v2/src/orxonox/sound/SoundManager.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/sound/SoundManager.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/sound/SoundManager.cc	(revision 10765)
@@ -83,5 +83,5 @@
             ThrowException(InitialisationAborted, "Sound: Not loading at all");
 #if !defined(ORXONOX_PLATFORM_APPLE)
-        if (!alutInitWithoutContext(NULL, NULL))
+        if (!alutInitWithoutContext(nullptr, nullptr))
             ThrowException(InitialisationFailed, "Sound Error: ALUT initialisation failed: " << alutGetErrorString(alutGetError()));
         Loki::ScopeGuard alutExitGuard = Loki::MakeGuard(&alutExit);
@@ -90,5 +90,5 @@
 /*
         // Get list of available sound devices and display them
-        const char* devices = alcGetString(NULL, ALC_DEVICE_SPECIFIER);
+        const char* devices = alcGetString(nullptr, ALC_DEVICE_SPECIFIER);
         char* device = new char[strlen(devices)+1];
         strcpy(device, devices);
@@ -110,12 +110,12 @@
         this->device_ = alcOpenDevice(renderDevice.c_str());
 */
-        this->device_ = alcOpenDevice(NULL);
-        if (this->device_ == NULL)
+        this->device_ = alcOpenDevice(nullptr);
+        if (this->device_ == nullptr)
             ThrowException(InitialisationFailed, "Sound Error: Could not open sound device.");
         Loki::ScopeGuard closeDeviceGuard = Loki::MakeGuard(&alcCloseDevice, this->device_);
 
         // Create sound context and make it the currently used one
-        this->context_ = alcCreateContext(this->device_, NULL);
-        if (this->context_ == NULL)
+        this->context_ = alcCreateContext(this->device_, nullptr);
+        if (this->context_ == nullptr)
             ThrowException(InitialisationFailed, "Sound Error: Could not create ALC context");
         Loki::ScopeGuard desroyContextGuard = Loki::MakeGuard(&alcDestroyContext, this->context_);
@@ -189,5 +189,5 @@
 
         // Relieve context to destroy it
-        if (!alcMakeContextCurrent(NULL))
+        if (!alcMakeContextCurrent(nullptr))
             orxout(internal_error, context::sound) << "Could not unset ALC context" << endl;
         alcDestroyContext(this->context_);
@@ -350,5 +350,5 @@
     void SoundManager::registerAmbientSound(AmbientSound* newAmbient)
     {
-        if (newAmbient != NULL && !this->bDestructorCalled_)
+        if (newAmbient != nullptr && !this->bDestructorCalled_)
         {
             for (AmbientList::const_iterator it = this->ambientSounds_.begin(); it != this->ambientSounds_.end(); ++it)
@@ -373,5 +373,5 @@
     void SoundManager::unregisterAmbientSound(AmbientSound* oldAmbient)
     {
-        if (oldAmbient == NULL || ambientSounds_.empty() || this->bDestructorCalled_)
+        if (oldAmbient == nullptr || ambientSounds_.empty() || this->bDestructorCalled_)
             return;
 
@@ -405,5 +405,5 @@
     void SoundManager::pauseAmbientSound(AmbientSound* ambient)
     {
-        if (ambient != NULL)
+        if (ambient != nullptr)
         {
             for (AmbientList::iterator it = this->ambientSounds_.begin(); it != this->ambientSounds_.end(); ++it)
Index: code/branches/cpp11_v2/src/orxonox/sound/SoundStreamer.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/sound/SoundStreamer.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/sound/SoundStreamer.cc	(revision 10765)
@@ -45,8 +45,8 @@
         vorbisCallbacks.seek_func  = &seekVorbis;
         vorbisCallbacks.tell_func  = &tellVorbis;
-        vorbisCallbacks.close_func = NULL;
+        vorbisCallbacks.close_func = nullptr;
 
         OggVorbis_File vf;
-        int ret = ov_open_callbacks(dataStream.get(), &vf, NULL, 0, vorbisCallbacks);
+        int ret = ov_open_callbacks(dataStream.get(), &vf, nullptr, 0, vorbisCallbacks);
         if (ret < 0)
         {
Index: code/branches/cpp11_v2/src/orxonox/worldentities/ControllableEntity.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/worldentities/ControllableEntity.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/worldentities/ControllableEntity.cc	(revision 10765)
@@ -62,5 +62,5 @@
         this->client_overwrite_ = 0;
         this->player_ = 0;
-        this->formerPlayer_ = NULL;
+        this->formerPlayer_ = nullptr;
         this->playerID_ = OBJECTID_UNKNOWN;
         this->hud_ = 0;
@@ -194,5 +194,5 @@
     bool ControllableEntity::setCameraPosition(unsigned int index)
     {
-        if(this->camera_ != NULL && this->cameraPositions_.size() > 0)
+        if(this->camera_ != nullptr && this->cameraPositions_.size() > 0)
         {
             if(index >= this->cameraPositions_.size())
@@ -350,5 +350,5 @@
         this->bHasLocalController_ = player->isLocalPlayer();
         this->bHasHumanController_ = player->isHumanPlayer();
-        if(controller_ != NULL)
+        if(controller_ != nullptr)
             this->team_ = controller_->getTeam(); // forward controller team number
 
@@ -434,8 +434,8 @@
     void ControllableEntity::destroyHud(void)
     {
-        if (this->hud_ != NULL)
+        if (this->hud_ != nullptr)
         {
             this->hud_->destroy();
-            this->hud_ = NULL;
+            this->hud_ = nullptr;
         }
     }
Index: code/branches/cpp11_v2/src/orxonox/worldentities/EffectContainer.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/worldentities/EffectContainer.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/worldentities/EffectContainer.cc	(revision 10765)
@@ -44,5 +44,5 @@
     EffectContainer::EffectContainer(Context* context)
         : BaseObject(context)
-        , lua_(NULL)
+        , lua_(nullptr)
     {
         RegisterObject(EffectContainer);
@@ -92,5 +92,5 @@
             if (i == index)
                 return (*it);
-        return NULL;
+        return nullptr;
     }
 
Index: code/branches/cpp11_v2/src/orxonox/worldentities/WorldEntity.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/worldentities/WorldEntity.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/worldentities/WorldEntity.cc	(revision 10765)
@@ -563,5 +563,5 @@
     void WorldEntity::detachOgreObject(Ogre::MovableObject* object)
     {
-        object->setUserAny(Ogre::Any(static_cast<OrxonoxClass*>(NULL)));
+        object->setUserAny(Ogre::Any(static_cast<OrxonoxClass*>(nullptr)));
         this->node_->detachObject(object);
     }
@@ -660,5 +660,5 @@
     {
         // If physics is enabled scale the attached CollisionShape.
-        /*if (this->hasPhysics() && this->collisionShape_ != NULL)
+        /*if (this->hasPhysics() && this->collisionShape_ != nullptr)
         {
             this->collisionShape_->setScale3D(scale);
Index: code/branches/cpp11_v2/src/orxonox/worldentities/pawns/ModularSpaceShip.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/worldentities/pawns/ModularSpaceShip.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/worldentities/pawns/ModularSpaceShip.cc	(revision 10765)
@@ -94,5 +94,5 @@
         for (unsigned int i=0; i < this->getAttachedObjects().size(); i++)
         {
-            if (this->getAttachedObject(i) == NULL)
+            if (this->getAttachedObject(i) == nullptr)
             {
                 break;
@@ -151,5 +151,5 @@
                 return it->second;
         }
-        return NULL;
+        return nullptr;
     }
 
@@ -160,5 +160,5 @@
     void ModularSpaceShip::damage(float damage, float healthdamage, float shielddamage, Pawn* originator, const btCollisionShape* cs)
     {
-        if (cs != NULL && this->getPartOfEntity((StaticEntity*)(cs->getUserPointer())) != NULL)
+        if (cs != nullptr && this->getPartOfEntity((StaticEntity*)(cs->getUserPointer())) != nullptr)
             this->getPartOfEntity((StaticEntity*)(cs->getUserPointer()))->handleHit(damage, healthdamage, shielddamage, originator);
         else
@@ -212,5 +212,5 @@
     void ModularSpaceShip::addShipPart(ShipPart* part)
     {
-        OrxAssert(part != NULL, "The ShipPart cannot be NULL.");
+        OrxAssert(part != nullptr, "The ShipPart cannot be nullptr.");
         this->partList_.push_back(part);
         part->setParent(this);
@@ -222,10 +222,10 @@
         Get the i-th ShipPart of the SpaceShip.
     @return
-        Returns a pointer to the i-the ShipPart. NULL if there is no ShipPart with that index.
+        Returns a pointer to the i-the ShipPart. nullptr if there is no ShipPart with that index.
     */
     ShipPart* ModularSpaceShip::getShipPart(unsigned int index)
     {
         if(this->partList_.size() <= index)
-            return NULL;
+            return nullptr;
         else
             return this->partList_[index];
@@ -238,5 +238,5 @@
         The name of the ShipPart to be returned.
     @return
-        Pointer to the ShipPart with the given name, or NULL if not found.
+        Pointer to the ShipPart with the given name, or nullptr if not found.
     */
     ShipPart* ModularSpaceShip::getShipPartByName(std::string name)
@@ -250,5 +250,5 @@
         }
         orxout(internal_warning) << "Couldn't find ShipPart with name \"" << name << "\"." << endl;
-        return NULL;
+        return nullptr;
     }
 
Index: code/branches/cpp11_v2/src/orxonox/worldentities/pawns/ModularSpaceShip.h
===================================================================
--- code/branches/cpp11_v2/src/orxonox/worldentities/pawns/ModularSpaceShip.h	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/worldentities/pawns/ModularSpaceShip.h	(revision 10765)
@@ -109,5 +109,5 @@
             ShipPart* getPartOfEntity(StaticEntity* entity) const;
 
-            virtual void damage(float damage, float healthdamage = 0.0f, float shielddamage = 0.0f, Pawn* originator = NULL, const btCollisionShape* cs = NULL);
+            virtual void damage(float damage, float healthdamage = 0.0f, float shielddamage = 0.0f, Pawn* originator = nullptr, const btCollisionShape* cs = nullptr);
 
             static void killShipPartStatic(std::string name);
Index: code/branches/cpp11_v2/src/orxonox/worldentities/pawns/Pawn.h
===================================================================
--- code/branches/cpp11_v2/src/orxonox/worldentities/pawns/Pawn.h	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/worldentities/pawns/Pawn.h	(revision 10765)
@@ -208,5 +208,5 @@
 
             //virtual void damage(float damage, Pawn* originator = 0);
-            virtual void damage(float damage, float healthdamage = 0.0f, float shielddamage = 0.0f, Pawn* originator = NULL, const btCollisionShape* cs = NULL);
+            virtual void damage(float damage, float healthdamage = 0.0f, float shielddamage = 0.0f, Pawn* originator = nullptr, const btCollisionShape* cs = nullptr);
 
             bool bAlive_;
@@ -215,5 +215,5 @@
                 { return new std::vector<PickupCarrier*>(); }
             virtual PickupCarrier* getCarrierParent(void) const
-                { return NULL; }
+                { return nullptr; }
 
 
Index: code/branches/cpp11_v2/src/orxonox/worldentities/pawns/SpaceShip.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/worldentities/pawns/SpaceShip.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/worldentities/pawns/SpaceShip.cc	(revision 10765)
@@ -48,5 +48,5 @@
     RegisterClass(SpaceShip);
 
-    SpaceShip::SpaceShip(Context* context) : Pawn(context), boostBlur_(NULL)
+    SpaceShip::SpaceShip(Context* context) : Pawn(context), boostBlur_(nullptr)
     {
         RegisterObject(SpaceShip);
@@ -196,5 +196,5 @@
             if(this->bEnableMotionBlur_)
             {
-                if (this->boostBlur_ == NULL && this->hasLocalController() && this->hasHumanController())
+                if (this->boostBlur_ == nullptr && this->hasLocalController() && this->hasHumanController())
                 {
                     this->boostBlur_ = new Shader(this->getScene()->getSceneManager());
@@ -305,5 +305,5 @@
     void SpaceShip::addEngine(orxonox::Engine* engine)
     {
-        OrxAssert(engine != NULL, "The engine cannot be NULL.");
+        OrxAssert(engine != nullptr, "The engine cannot be nullptr.");
         this->engineList_.push_back(engine);
         engine->addToSpaceShip(this);
@@ -330,10 +330,10 @@
         Get the i-th Engine of the SpaceShip.
     @return
-        Returns a pointer to the i-the Engine. NULL if there is no Engine with that index.
+        Returns a pointer to the i-the Engine. nullptr if there is no Engine with that index.
     */
     Engine* SpaceShip::getEngine(unsigned int i)
     {
         if(this->engineList_.size() >= i)
-            return NULL;
+            return nullptr;
         else
             return this->engineList_[i];
@@ -346,5 +346,5 @@
         The name of the engine to be returned.
     @return
-        Pointer to the engine with the given name, or NULL if not found.
+        Pointer to the engine with the given name, or nullptr if not found.
     */
     Engine* SpaceShip::getEngineByName(const std::string& name)
@@ -355,5 +355,5 @@
 
         orxout(internal_warning) << "Couldn't find Engine with name \"" << name << "\"." << endl;
-        return NULL;
+        return nullptr;
     }
 
@@ -465,8 +465,8 @@
     void SpaceShip::changedEnableMotionBlur()
     {
-        if (!this->bEnableMotionBlur_ && this->boostBlur_ != NULL)
+        if (!this->bEnableMotionBlur_ && this->boostBlur_ != nullptr)
         {
             delete this->boostBlur_;
-            this->boostBlur_ = NULL;
+            this->boostBlur_ = nullptr;
         }
     }
@@ -510,5 +510,5 @@
     {
         Camera* camera = CameraManager::getInstance().getActiveCamera();
-        if(camera != NULL)
+        if(camera != nullptr)
         {
             this->cameraOriginalPosition_ = camera->getPosition();

Index: code/branches/cpp11_v2/src/orxonox/collisionshapes/CompoundCollisionShape.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/collisionshapes/CompoundCollisionShape.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/collisionshapes/CompoundCollisionShape.cc	(revision 10765)
@@ -72,10 +72,10 @@
                 it->first->destroy();
                 if (this->collisionShape_ == it->second)
-                    this->collisionShape_ = NULL; // don't destroy it twice
+                    this->collisionShape_ = nullptr; // don't destroy it twice
             }
 
             delete this->compoundShape_;
             if (this->collisionShape_ == this->compoundShape_)
-                this->collisionShape_ = NULL; // don't destroy it twice
+                this->collisionShape_ = nullptr; // don't destroy it twice
         }
     }
@@ -96,5 +96,5 @@
     void CompoundCollisionShape::attach(CollisionShape* shape)
     {
         // If either the input shape is NULL or we try to attach the CollisionShape to itself.
         if (!shape || static_cast<CollisionShape*>(this) == shape)
             return;
@@ -96,5 +96,5 @@
     void CompoundCollisionShape::attach(CollisionShape* shape)
     {
-        // If either the input shape is NULL or we try to attach the CollisionShape to itself.
+        // If either the input shape is nullptr or we try to attach the CollisionShape to itself.
         if (!shape || static_cast<CollisionShape*>(this) == shape)
             return;
Index: code/branches/cpp11_v2/src/orxonox/interfaces/Pickupable.cc
===================================================================
--- code/branches/cpp11_v2/src/orxonox/interfaces/Pickupable.cc	(revision 10733)
+++ code/branches/cpp11_v2/src/orxonox/interfaces/Pickupable.cc	(revision 10765)
@@ -56,5 +56,5 @@
         RegisterObject(Pickupable);
 
-        this->carrier_ = NULL;
+        this->carrier_ = nullptr;
 
         this->beingDestroyed_ = false;
@@ -143,5 +143,5 @@
     bool Pickupable::isTarget(const PickupCarrier* carrier) const
     {
-        if(carrier == NULL)
+        if(carrier == nullptr)
             return false;
 
@@ -210,5 +210,5 @@
     bool Pickupable::pickup(PickupCarrier* carrier)
     {
-        if(carrier == NULL || this->isPickedUp()) // If carrier is NULL or the Pickupable is already picked up.
+        if(carrier == nullptr || this->isPickedUp()) // If carrier is nullptr or the Pickupable is already picked up.
             return false;
 
@@ -237,5 +237,5 @@
             return false;
 
-        assert(this->getCarrier()); // The Carrier cannot be NULL at this point.
+        assert(this->getCarrier()); // The Carrier cannot be nullptr at this point.
         if(!this->getCarrier()->removePickup(this)) //TODO Shouldn't this be a little later?
             orxout(internal_warning, context::pickups) << "Pickupable (&" << this << ", " << this->getIdentifier()->getName() << ") is being dropped, but it was not present in the PickupCarriers list of pickups." << endl;
@@ -249,5 +249,5 @@
             created = this->createSpawner();
 
-        this->setCarrier(NULL);
+        this->setCarrier(nullptr);
 
         if(!created && createSpawner) // If a PickupSpawner should have been created but wasn't.
@@ -301,5 +301,5 @@
         orxout(verbose, context::pickups) << "Pickupable (&" << this << ") changed Carrier (& " << carrier << ")." << endl;
 
-        if(carrier != NULL && tell)
+        if(carrier != nullptr && tell)
         {
             if(!carrier->addPickup(this))